@@ -1,31 +1,33 @@
+"""Author FredHappyface 2020...
 
-"""
-Author FredHappyface 2020
 Uses pyppeteer to leverage a headless version of Chromium
 """
+from __future__ import annotations
+
 import asyncio
 from os import remove
-from pyppeteer import launch
+
 from PIL import Image
-from metprint import LogType, Logger, FHFormatter
+from pyppeteer import launch
+
 
 async def doGrabWebpage(url, resolution, evalJs):
-	''' Go to a URL, with a browser with a set resolution and run some js
-	then take a screenshot'''
-	browser = await launch(options={'args': ['--no-sandbox', '--disable-web-security']})
+	"""Go to a URL, with a browser with a set resolution and run some js then take a screenshot."""
+	browser = await launch(options={"args": ["--no-sandbox", "--disable-web-security"]})
 	page = await browser.newPage()
 	await page.setViewport({"width": resolution[0], "height": resolution[1]})
 	await page.goto(url)
 	if evalJs is not None:
 		await page.evaluate(evalJs)
-	await page.screenshot({'path': 'temp.png'})
+	await page.screenshot({"path": "temp.png"})
 	await browser.close()
 
-def grabWebpage(url, resolution=(800, 600), evalJs=None):
-	"""Take a screenshot of a webpage
+
+def grabWebpage(url: str, resolution: tuple[int, int] = (800, 600), evalJs=None):
+	"""Take a screenshot of a webpage...
 
 	Args:
-		url (string): The url of the webpage in question
+		url (str): The url of the webpage in question
 		resolution ((int,int)), optional): Set the page resolution
 		evalJs (string): Javascript to run on the page
 
@@ -37,6 +39,7 @@ def grabWebpage(url, resolution=(800, 600), evalJs=None):
 	try:
 		remove("temp.png")
 	except PermissionError:
-		Logger(FHFormatter()).logPrint("Unable to clean up, manually " +
-			"remove temp.png from project root or ignore", LogType.WARNING)
+		print(
+			"WARNING: Unable to clean up, manually " + "remove temp.png from project root or ignore"
+		)
 	return image
